# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.style
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.font_slant import FontSlant as FontSlant_849509ed
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from ..lang.locale import Locale as Locale_70d308fa
    from ..table.border_line2 import BorderLine2 as BorderLine2_af200b28
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from ..util.color import Color as Color_68e908c5

class CharacterProperties(ABC):
    """
    Service Class

    This is a set of properties to describe the style of characters.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API CharacterProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1CharacterProperties.html>`_
    """
    @property
    def CharInteropGrabBag(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Grab bag of character properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.3
        """
    @property
    def CharStyleNames(self) -> 'typing.Tuple[str, ...]':
        """
        This optional property specifies the names of the all styles applied to the font.
        
        It is not guaranteed that the order in the sequence reflects the order of the evaluation of the character style attributes.
        
        **since**
        
            OOo 1.1.2
        """
    @property
    def CharAutoKerning(self) -> bool:
        """
        This optional property determines whether the kerning tables from the current font are used.
        
        Automatic kerning applies a spacing in between certain pairs of characters to make the text look better.
        """
    @property
    def CharBackColor(self) -> 'Color_68e908c5':
        """
        This optional property contains the text background color.
        """
    @property
    def CharBackTransparent(self) -> bool:
        """
        This property determines if the text background color is set to transparent.
        """
    @property
    def CharBorderDistance(self) -> int:
        """
        This property contains the distance from the border to the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharBottomBorder(self) -> 'BorderLine2_af200b28':
        """
        This property contains the bottom border of the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharBottomBorderDistance(self) -> int:
        """
        This property contains the distance from the bottom border to the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharCaseMap(self) -> int:
        """
        This optional property contains the value of the case-mapping of the text for formatting and displaying.
        """
    @property
    def CharColor(self) -> 'Color_68e908c5':
        """
        This property contains the value of the text color.
        """
    @property
    def CharCombineIsOn(self) -> bool:
        """
        This optional property determines whether text is formatted in two lines.
        
        It is linked to the properties CharCombinePrefix and CharCombineSuffix.
        """
    @property
    def CharCombinePrefix(self) -> str:
        """
        This optional property contains the prefix (usually parenthesis) before text that is formatted in two lines.
        
        It is linked to the properties CharCombineIsOn and CharCombineSuffix.
        """
    @property
    def CharCombineSuffix(self) -> str:
        """
        This optional property contains the suffix (usually parenthesis) after text that is formatted in two lines.
        
        It is linked to the properties CharCombineIsOn and CharCombinePrefix.
        """
    @property
    def CharContoured(self) -> bool:
        """
        This optional property specifies if the characters are formatted and displayed with a contour effect.
        """
    @property
    def CharCrossedOut(self) -> bool:
        """
        This property is TRUE if the characters are crossed out.
        """
    @property
    def CharEmphasis(self) -> int:
        """
        This optional property contains the font emphasis value.
        """
    @property
    def CharEscapement(self) -> int:
        """
        specifies the percentage by which to raise/lower superscript/subscript characters.
        
        Negative values denote subscripts and positive values superscripts.
        """
    @property
    def CharEscapementHeight(self) -> int:
        """
        This is the relative height used for subscript or superscript characters in units of percent.
        
        The value 100 denotes the original height of the characters.
        """
    @property
    def CharFlash(self) -> bool:
        """
        If this optional property is TRUE, then the characters are flashing.
        """
    @property
    def CharFontCharSet(self) -> int:
        """
        This property contains the text encoding of the font.
        """
    @property
    def CharFontFamily(self) -> int:
        """
        This property contains font family.
        """
    @property
    def CharFontName(self) -> str:
        """
        This property specifies the name of the font style.
        
        It may contain more than one name separated by comma.
        """
    @property
    def CharFontPitch(self) -> int:
        """
        This property contains the font pitch.
        """
    @property
    def CharFontStyleName(self) -> str:
        """
        This property contains the name of the font style.
        
        This property may be empty.
        """
    @property
    def CharFontType(self) -> int:
        """
        This optional property specifies the fundamental technology of the font.
        """
    @property
    def CharHeight(self) -> float:
        """
        This value contains the height of the characters in point.
        """
    @property
    def CharHidden(self) -> bool:
        """
        If this optional property is TRUE, then the characters are invisible.
        
        **since**
        
            OOo 2.0
        """
    @property
    def CharHighlight(self) -> 'Color_68e908c5':
        """
        Determines the color of the highlight.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharKeepTogether(self) -> bool:
        """
        This optional property marks a range of characters to prevent it from being broken into two lines.
        
        A line break is applied before the range of characters if the layout makes a break necessary within the range.
        """
    @property
    def CharKerning(self) -> int:
        """
        This optional property contains the value of the kerning of the characters.
        """
    @property
    def CharLeftBorder(self) -> 'BorderLine2_af200b28':
        """
        This property contains the left border of the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharLeftBorderDistance(self) -> int:
        """
        This property contains the distance from the left border to the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharLocale(self) -> 'Locale_70d308fa':
        """
        This property contains the value of the locale.
        """
    @property
    def CharNoHyphenation(self) -> bool:
        """
        This optional property determines if the word can be hyphenated at the character.
        """
    @property
    def CharNoLineBreak(self) -> bool:
        """
        This optional property marks a range of characters to ignore a line break in this area.
        
        A line break is applied behind the range of characters if the layout makes a break necessary within the range. That means that the text may go through the border.
        """
    @property
    def CharPosture(self) -> 'FontSlant_849509ed':
        """
        This property contains the value of the posture of the document.
        """
    @property
    def CharRelief(self) -> int:
        """
        This optional property contains the relief style of the characters.
        """
    @property
    def CharRightBorder(self) -> 'BorderLine2_af200b28':
        """
        This property contains the right border of the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharRightBorderDistance(self) -> int:
        """
        This property contains the distance from the right border to the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharRotation(self) -> int:
        """
        This optional property determines the rotation of a character in tenths of a degree.
        
        Depending on the implementation only certain values may be allowed.
        """
    @property
    def CharRotationIsFitToLine(self) -> bool:
        """
        This optional property determines whether the text formatting tries to fit rotated text into the surrounded line height.
        """
    @property
    def CharScaleWidth(self) -> int:
        """
        This optional property determines the percentage value for scaling the width of characters.
        
        The value refers to the original width which is denoted by 100, and it has to be greater than 0.
        """
    @property
    def CharShadingValue(self) -> int:
        """
        This optional property contains the text shading value.
        """
    @property
    def CharShadowFormat(self) -> 'ShadowFormat_bb840bdf':
        """
        Determines the type, color, and width of the shadow.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharShadowed(self) -> bool:
        """
        This optional property specifies if the characters are formatted and displayed with a shadow effect.
        """
    @property
    def CharStrikeout(self) -> int:
        """
        This property determines the type of the strike out of the character.
        """
    @property
    def CharStyleName(self) -> str:
        """
        This optional property specifies the name of the style of the font.
        """
    @property
    def CharTopBorder(self) -> 'BorderLine2_af200b28':
        """
        This property contains the top border of the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharTopBorderDistance(self) -> int:
        """
        This property contains the distance from the top border to the object.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def CharTransparence(self) -> int:
        """
        This is the transparency of the character text.
        
        The value 100 means entirely transparent, while 0 means not transparent at all.
        
        **since**
        
            LibreOffice 7.0
        """
    @property
    def CharUnderline(self) -> int:
        """
        This property contains the value for the character underline.
        """
    @property
    def CharUnderlineColor(self) -> 'Color_68e908c5':
        """
        This property contains the color of the underline for the characters.
        """
    @property
    def CharUnderlineHasColor(self) -> bool:
        """
        This property specifies if the property CharUnderlineColor is used for an underline.
        """
    @property
    def CharWeight(self) -> float:
        """
        This property contains the value of the font weight.
        """
    @property
    def CharWordMode(self) -> bool:
        """
        If this property is TRUE, the underline and strike-through properties are not applied to white spaces.
        """
    @property
    def HyperLinkName(self) -> str:
        """
        This optional property contains the name of the hyperlink.
        """
    @property
    def HyperLinkTarget(self) -> str:
        """
        This optional property contains the name of the target for a hyperlink.
        """
    @property
    def HyperLinkURL(self) -> str:
        """
        This optional property contains the URL of a hyperlink.
        """
    @property
    def RubyAdjust(self) -> int:
        """
        This optional property determines the adjustment of the ruby .
        """
    @property
    def RubyCharStyleName(self) -> str:
        """
        This optional property contains the name of the character style that is applied to RubyText.
        """
    @property
    def RubyIsAbove(self) -> bool:
        """
        This optional property determines whether the ruby text is printed above/left or below/right of the text.
        
        This property is replaced by RubyPosition.
        """
    @property
    def RubyPosition(self) -> int:
        """
        This optional property determines the position of the ruby .
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def RubyText(self) -> str:
        """
        This optional property contains the text that is set as ruby.
        """
    @property
    def TextUserDefinedAttributes(self) -> 'XNameContainer_cb90e47':
        """
        This property stores XML attributes.
        
        They will be saved to and restored from automatic styles inside XML files.
        """
    @property
    def UnvisitedCharStyleName(self) -> str:
        """
        This optional property contains the character style name for unvisited hyperlinks.
        """
    @property
    def VisitedCharStyleName(self) -> str:
        """
        This optional property contains the character style name for visited hyperlinks.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from .x_task import XTask as XTask_712808fe

class Task(XTask_712808fe):
    """
    Service Class

    represents a top level frame in the frame hierarchy with the desktop as root
    
    Please use the service Frame instead of this deprecated Task. If it's method XFrame.isTop() returns TRUE, it's the same as a check for the Task service.
    
    **since**
    
        OOo 1.1.2
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API Task <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1Task.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_fast_attribute_list import XFastAttributeList as XFastAttributeList_274d0f09

class XFastContextHandler(XInterface_8f010a43):
    """
    receives notification of sax document events from a XFastParser.

    See Also:
        `API XFastContextHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastContextHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XFastContextHandler']

    def characters(self, aChars: str) -> None:
        """
        receives notification of character data.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def createFastChildContext(self, Element: int, Attribs: 'XFastAttributeList_274d0f09') -> 'XFastContextHandler':
        """
        receives notification of the beginning of a known child element.
        
        If the element has a namespace that was registered with the XFastParser, Element contains the integer token of the elements local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def createUnknownChildContext(self, Namespace: str, Name: str, Attribs: 'XFastAttributeList_274d0f09') -> 'XFastContextHandler':
        """
        receives notification of the beginning of an unknown child element .

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def endFastElement(self, Element: int) -> None:
        """
        receives notification of the end of a known element.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def endUnknownElement(self, Namespace: str, Name: str) -> None:
        """
        receives notification of the end of a known element.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def startFastElement(self, Element: int, Attribs: 'XFastAttributeList_274d0f09') -> None:
        """
        receives notification of the beginning of an element .
        
        If the element has a namespace that was registered with the XFastParser, Element contains the integer token of the elements local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def startUnknownElement(self, Namespace: str, Name: str, Attribs: 'XFastAttributeList_274d0f09') -> None:
        """
        receives notification of the beginning of an unknown element .

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d

class XUIElementSettings(XInterface_8f010a43):
    """
    provides functions to retrieve and change user interface element structure data and to update its visible representation.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIElementSettings <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIElementSettings.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XUIElementSettings']

    def getSettings(self, bWriteable: bool) -> 'XIndexAccess_f0910d6d':
        """
        provides a UIElementSettings instance that provides access to the structure of user interface element if the user interface element type supports it.
        """
    def setSettings(self, UISettings: 'XIndexAccess_f0910d6d') -> None:
        """
        set changes to the structure of the user interface element.
        
        User interface elements cannot be changed directly. The changed structure data has to be set again. This speeds up the configuration process if many changes have to be made on the structure. The persistence of changes are controlled by the boolean property Persistent.
        """
    def updateSettings(self) -> None:
        """
        forces the user interface element to retrieve new settings from its configuration source.
        
        This is not done automatically as configurable user interface elements are controlled by layout managers. It is more efficient to let the responsible layout manager to control the update process in a single task.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .solver_constraint_operator import SolverConstraintOperator as SolverConstraintOperator_6e4a110d
from ..table.cell_address import CellAddress as CellAddress_ae5f0b56


class SolverConstraint(object):
    """
    Struct Class

    is used to specify a constraint for a solver model.

    See Also:
        `API SolverConstraint <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1SolverConstraint.html>`_
    """
    typeName: Literal['com.sun.star.sheet.SolverConstraint']

    def __init__(self, Left: typing.Optional[CellAddress_ae5f0b56] = ..., Operator: typing.Optional[SolverConstraintOperator_6e4a110d] = ..., Right: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Left (CellAddress, optional): Left value.
            Operator (SolverConstraintOperator, optional): Operator value.
            Right (object, optional): Right value.
        """


    @property
    def Left(self) -> CellAddress_ae5f0b56:
        """
        The address of the cell that is constrained.
        """


    @property
    def Operator(self) -> SolverConstraintOperator_6e4a110d:
        """
        The type of the constraint.
        """


    @property
    def Right(self) -> object:
        """
        The comparison value, of type double or com.sun.star.table.CellAddress.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These values define the type of bibliographic data like book, journal, magazine, etc.

See Also:
    `API BibliographyDataType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html>`_
"""
ARTICLE: Literal[0]
"""
An article from a journal or magazine.
"""
BOOK: Literal[1]
"""
A book with an explicit publisher.
"""
BOOKLET: Literal[2]
"""
A work that is printed and bound, but without a named publisher or sponsoring institution.
"""
CONFERENCE: Literal[3]
"""
An article in the proceedings of a conference.

This entry is identical to the \"inproceedings\" entry and is included for compatibility with BiBTex.
"""
INBOOK: Literal[4]
"""
A part of a book, which may be a chapter and/or a range of pages.
"""
INCOLLECTION: Literal[5]
"""
A part of a book with its own title.
"""
INPROCEEDINGS: Literal[6]
"""
An article in the proceedings of a conference.
"""
JOURNAL: Literal[7]
"""
A journal or magazine.
"""
MANUAL: Literal[8]
"""
Technical documentation.
"""
MASTERSTHESIS: Literal[9]
"""
A Master's thesis.
"""
MISC: Literal[10]
"""
This type is used when nothing else seems appropriate.
"""
PHDTHESIS: Literal[11]
"""
A PhD thesis.
"""
PROCEEDINGS: Literal[12]
"""
The proceedings of a conference.
"""
TECHREPORT: Literal[13]
"""
A report published by a school or other institution, usually numbered within a series.
"""
UNPUBLISHED: Literal[14]
"""
A document with an author and title, but not formally published.
"""
EMAIL: Literal[15]
"""
An eMail document.
"""
WWW: Literal[16]
"""
A Web document.
"""
CUSTOM1: Literal[17]
"""
A user defined document type.
"""
CUSTOM2: Literal[18]
"""
A user defined document type.
"""
CUSTOM3: Literal[19]
"""
A user defined document type.
"""
CUSTOM4: Literal[20]
"""
A user defined document type.
"""
CUSTOM5: Literal[21]
"""
A user defined document type.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
"""
Const

The ShadingPattern determines the background color pattern against which characters and graphics are displayed, typically in tables.

The color can be no color or it can be a specific color with a transparency or pattern value.

See Also:
    `API ShadingPattern <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html>`_
"""
CLEAR: Literal[0]
SOLID: Literal[1]
PCT5: Literal[2]
PCT10: Literal[3]
PCT20: Literal[4]
PCT25: Literal[5]
PCT30: Literal[6]
PCT40: Literal[7]
PCT50: Literal[8]
PCT60: Literal[9]
PCT70: Literal[10]
PCT75: Literal[11]
PCT80: Literal[12]
PCT90: Literal[13]
HORZ_STRIPE: Literal[14]
VERT_STRIPE: Literal[15]
REVERSE_DIAG_STRIPE: Literal[16]
DIAG_STRIPE: Literal[17]
HORZ_CROSS: Literal[18]
DIAG_CROSS: Literal[19]
THIN_HORZ_STRIPE: Literal[20]
THIN_VERT_STRIPE: Literal[21]
THIN_REVERSE_DIAG_STRIPE: Literal[22]
THIN_DIAG_STRIPE: Literal[23]
THIN_HORZ_CROSS: Literal[24]
THIN_DIAG_CROSS: Literal[25]
UNUSED_1: Literal[26]
UNUSED_2: Literal[27]
UNUSED_3: Literal[28]
UNUSED_4: Literal[29]
UNUSED_5: Literal[30]
UNUSED_6: Literal[31]
UNUSED_7: Literal[32]
UNUSED_8: Literal[33]
UNUSED_9: Literal[34]
PCT2: Literal[35]
PCT7: Literal[36]
PCT12: Literal[37]
PCT15: Literal[38]
PCT17: Literal[39]
PCT22: Literal[40]
PCT27: Literal[41]
PCT32: Literal[42]
PCT35: Literal[43]
PCT37: Literal[44]
PCT42: Literal[45]
PCT45: Literal[46]
PCT47: Literal[47]
PCT52: Literal[48]
PCT55: Literal[49]
PCT57: Literal[50]
PCT62: Literal[51]
PCT65: Literal[52]
PCT67: Literal[53]
PCT72: Literal[54]
PCT77: Literal[55]
PCT82: Literal[56]
PCT85: Literal[57]
PCT87: Literal[58]
PCT92: Literal[59]
PCT95: Literal[60]
PCT97: Literal[61]
NIL: Literal[65535]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content import XContent as XContent_79db0975
    from .x_content_identifier import XContentIdentifier as XContentIdentifier_edc90d78

class XContentProvider(XInterface_8f010a43):
    """
    a content provider which creates and manages XContents.

    See Also:
        `API XContentProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XContentProvider']

    def compareContentIds(self, Id1: 'XContentIdentifier_edc90d78', Id2: 'XContentIdentifier_edc90d78') -> int:
        """
        compares two XContentIdentifiers.
        """
    def queryContent(self, Identifier: 'XContentIdentifier_edc90d78') -> 'XContent_79db0975':
        """
        creates a new XContent instance, if the given XContentIdentifier matches a content provided by the implementation of this interface.

        Raises:
            com.sun.star.ucb.IllegalIdentifierException: ``IllegalIdentifierException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.binding
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_list_entry_listener import XListEntryListener as XListEntryListener_78de1111

class XListEntrySource(XInterface_8f010a43):
    """
    specifies a source of string list entries
    
    The interface supports foreign components which actively retrieve list entries, as well as components which want to passively being notified of changes in the list.

    See Also:
        `API XListEntrySource <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntrySource.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.binding.XListEntrySource']

    def addListEntryListener(self, Listener: 'XListEntryListener_78de1111') -> None:
        """
        adds a listener which will be notified about changes in the list reflected by the component.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
    def getAllListEntries(self) -> 'typing.Tuple[str, ...]':
        """
        provides access to the entirety of all list entries
        """
    def getListEntry(self, Position: int) -> str:
        """
        provides access to a single list entry

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getListEntryCount(self) -> int:
        """
        retrieves the number of entries in the list
        """
    def removeListEntryListener(self, Listener: 'XListEntryListener_78de1111') -> None:
        """
        revokes the given listener from the list of components which will be notified about changes in the entry list.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XDataAccessDescriptorFactory(ABC):
    """
    allows creating instances of the DataAccessDescriptor service.
    
    Data access descriptors are finally only bags of properties with a defined semantics. Depending on the context in which you use them, certain of their properties are needed or unneeded.
    The descriptor factory allows you to create instances which offer all properties potentially needed at a descriptor.

    See Also:
        `API XDataAccessDescriptorFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDataAccessDescriptorFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XDataAccessDescriptorFactory']

    def createDataAccessDescriptor(self) -> 'XPropertySet_bc180bfa':
        """
        creates a DataAccessDescriptor which supports all properties defined for this service, even if they're normally optional only.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from .x_accessible_text import XAccessibleText as XAccessibleText_5b77105b
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XAccessibleEditableText(XAccessibleText_5b77105b):
    """
    Implement this interface to give read and write access to a text representation.
    
    This interface is typically used in conjunction with the XAccessibleText interface and extents it about the ability to modify the text represented by that interface.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleEditableText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEditableText.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleEditableText']

    def cutText(self, nStartIndex: int, nEndIndex: int) -> bool:
        """
        Copies the text range into the clipboard.
        
        The specified text between and including the two given indices is copied into the system clipboard and is deleted afterwards from the text represented by this object. This is equivalent to calling first XAccessibleText.copyText() and then XAccessibleEditableText.deleteText() with the given start and end indices.
        
        The text indices are interpreted like those in the XAccessibleText.getTextRange() method.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def deleteText(self, nStartIndex: int, nEndIndex: int) -> bool:
        """
        Deletes a range of text.
        
        The text between and including the two given indices is deleted from the text represented by this object.
        
        The text indices are interpreted like those in the XAccessibleText.getTextRange() method.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def insertText(self, sText: str, nIndex: int) -> bool:
        """
        Inserts text at the specified position.
        
        The specified string is inserted at the given index into the text represented by this object.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def pasteText(self, nIndex: int) -> bool:
        """
        Pastes text from the clipboard.
        
        The text in the system clipboard is pasted into the text represented by this object at the given index. This method is similar to the XAccessibleEditableText.insertText() method. If the index is not valid then the system clipboard text is not inserted.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def replaceText(self, nStartIndex: int, nEndIndex: int, sReplacement: str) -> bool:
        """
        Replaces text.
        
        The text between the two given indices is replaced by the specified replacement string. This method is equivalent to calling first XAccessibleEditableText.deleteText() with the two indices and afterwards calling XAccessibleEditableText.insertText() with the replacement text and the start index.
        
        The text indices are interpreted like those in the XAccessibleText.getTextRange() method.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setAttributes(self, nStartIndex: int, nEndIndex: int, aAttributeSet: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> bool:
        """
        Replaces the attributes of a text range by the given set of attributes.
        
        Sets the attributes for the text between and including the two given indices to those given. The old attributes of this text portion are replaced by the new list of attributes.
        
        The text indices are interpreted like those in the XAccessibleText.getTextRange() method.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setText(self, sText: str) -> bool:
        """
        Replaces the whole text with the given text.
        
        The text content of this object is set to the given string.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.inspection
from ...inspection.x_property_handler import XPropertyHandler as XPropertyHandler_3e950fbf

class CellBindingPropertyHandler(XPropertyHandler_3e950fbf):
    """
    Service Class

    implements a property handler for use with a com.sun.star.inspection.ObjectInspector which is able to provide properties to bind a form component to a spreadsheet cell.
    
    The handler expects a value named \"ContextDocument\" in the context in which it is created. That is, the com.sun.star.uno.XComponentContext used for creating the CellBindingPropertyHandler is examined for a value with this name. If the object in this value denotes a spreadsheet document (indicated by supporting the com.sun.star.sheet.XSpreadsheetDocument interface), this document is used to create the com.sun.star.form.binding.ValueBindings to bind the inspected object to cells in this document.

    See Also:
        `API CellBindingPropertyHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1CellBindingPropertyHandler.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing.framework
# Libre Office Version: 7.2
from typing_extensions import Literal
from ...lang.event_object import EventObject as EventObject_a3d70b03
import typing
from .x_configuration import XConfiguration as XConfiguration_8f0511a0
from .x_resource_id import XResourceId as XResourceId_5be3103d
from ...uno.x_interface import XInterface as XInterface_8f010a43


class ConfigurationChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    Objects of this class are used for notifying changes of the configuration.
    
    They are broadcasted by the configuration controller which maintains the configuration. The set of types of configuration changes is not fixed and is not maintained or documented in one place.
    
    The set of used members and the exact meaning of their values is not the same for all types. Therefore, the descriptions of the members are just general guidelines. See XConfigurationController for a list of event types used by the basic drawing framework.

    See Also:
        `API ConfigurationChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1framework_1_1ConfigurationChangeEvent.html>`_
    """
    typeName: Literal['com.sun.star.drawing.framework.ConfigurationChangeEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Type: typing.Optional[str] = ..., Configuration: typing.Optional[XConfiguration_8f0511a0] = ..., ResourceId: typing.Optional[XResourceId_5be3103d] = ..., ResourceObject: typing.Optional[XInterface_8f010a43] = ..., UserData: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Type (str, optional): Type value.
            Configuration (XConfiguration, optional): Configuration value.
            ResourceId (XResourceId, optional): ResourceId value.
            ResourceObject (XInterface, optional): ResourceObject value.
            UserData (object, optional): UserData value.
        """


    @property
    def Type(self) -> str:
        """
        The type of configuration change is a free-form string.
        
        This is the only member that is always set. The values of the other members depend on the configuration change type and may or may not be set.
        """


    @property
    def Configuration(self) -> XConfiguration_8f0511a0:
        """
        The current configuration, depending on the event type, either before or after the change.
        
        May be an empty reference.
        """


    @property
    def ResourceId(self) -> XResourceId_5be3103d:
        """
        The resource id that is part of the configuration change.
        """


    @property
    def ResourceObject(self) -> XInterface_8f010a43:
        """
        The resource object that corresponds to the ResourceId.
        
        May be an empty reference.
        """


    @property
    def UserData(self) -> object:
        """
        Each listener is called with exactly the UserData that was given when the listener was registered.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class VertOrientationFormat(object):
    """
    Struct Class

    describes the vertical orientation of an object.
    
    If VerticalOrientation == VERT_NONE, then the value \"YPos\" describes the distance from the top of the context. Otherwise \"YPos\" is ignored.

    See Also:
        `API VertOrientationFormat <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1VertOrientationFormat.html>`_
    """
    typeName: Literal['com.sun.star.text.VertOrientationFormat']

    def __init__(self, YPos: typing.Optional[int] = ..., VerticalOrientation: typing.Optional[int] = ..., VerticalRelation: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            YPos (int, optional): YPos value.
            VerticalOrientation (int, optional): VerticalOrientation value.
            VerticalRelation (int, optional): VerticalRelation value.
        """


    @property
    def YPos(self) -> int:
        """
        contains the distance from top.
        
        Only valid if the property VerticalOrientation contains the value VERT_NONE.
        """


    @property
    def VerticalOrientation(self) -> int:
        """
        determines the vertical alignment of an object.
        
        The values refer to com.sun.star.VertOrientation.
        """


    @property
    def VerticalRelation(self) -> int:
        """
        determines the reference position of the vertical alignment.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from .x_window import XWindow as XWindow_713b0924
if typing.TYPE_CHECKING:
    from .size import Size as Size_576707ef

class XWindow2(XWindow_713b0924):
    """
    specifies some extended operations for a window component.
    
    A window is a rectangular region on an output device with its own position, size, and internal coordinate system. A window is used for displaying data. In addition, the window receives events from the user.

    See Also:
        `API XWindow2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XWindow2']

    def getOutputSize(self) -> 'Size_576707ef':
        """
        returns the inner bounds of the window, also known as the client size.
        """
    def hasFocus(self) -> bool:
        """
        returns the focus state of the window
        """
    def isActive(self) -> bool:
        """
        returns the activation state of the window
        """
    def isEnabled(self) -> bool:
        """
        returns the enabled state of the window
        """
    def isVisible(self) -> bool:
        """
        returns the visibility state of the window
        """
    def setOutputSize(self, Size: 'Size_576707ef') -> None:
        """
        sets the inner bounds of the window, also known as the client size
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from .x_driver import XDriver as XDriver_79f30968

class Driver(XDriver_79f30968):
    """
    Service Class

    is the service that every driver class must implement.
    
    Each driver should supply a service that implements the Driver interface.
    
    The DriverManager will try to load as many drivers as it can find and then for any given connection request, it will ask each driver in turn to try to connect to the target URL.
    
    It is strongly recommended that each Driver object should be small and standalone so that the Driver object can be loaded and queried without bringing in vast quantities of supporting code.
    
    Each driver should be a one instance service.

    See Also:
        `API Driver <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1Driver.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
from typing_extensions import Literal
"""
Const

This constants set contains possible verbs for a contained object.

See Also:
    `API EmbedVerbs <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedVerbs.html>`_
"""
MS_OLEVERB_PRIMARY: Literal[0]
"""
lets the object do default activation, as by double-click.
"""
MS_OLEVERB_SHOW: Literal[-1]
"""
lets the object open itself for editing of viewing.
"""
MS_OLEVERB_OPEN: Literal[-2]
"""
lets the object activate itself outplace.
"""
MS_OLEVERB_HIDE: Literal[-3]
"""
lets the inplace object remove its UI from container.
"""
MS_OLEVERB_UIACTIVATE: Literal[-4]
"""
lets the object proceed with UI activation.
"""
MS_OLEVERB_IPACTIVATE: Literal[-5]
"""
lets the object activate itself inplace.
"""
MS_OLEVERB_DISCARDUNDOSTATE: Literal[-6]
"""
lets the object forget any undo state.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_controller import XController as XController_b00e0b8f
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XModel(XComponent_98dc0ab5):
    """
    represents a component which is created from a URL and arguments.
    
    It is a representation of a resource in the sense that it was created/loaded from the resource. The arguments are passed to the loader to modify its behavior. An example for such an argument is \"AsTemplate\", which loads the resource as a template for a new document. (see com.sun.star.document.MediaDescriptor for further details)
    
    Models can be controlled by controller components, which are usually views of the model. (see Controller for further details)
    
    If there is at least one controller, there is by definition a current controller. And if that controller supports the interface com.sun.star.view.XSelectionSupplier, it has a current selection too.

    See Also:
        `API XModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XModel']

    def attachResource(self, URL: str, Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> bool:
        """
        informs a model about its resource description.
        """
    def connectController(self, Controller: 'XController_b00e0b8f') -> None:
        """
        is called whenever a new controller is created for this model.
        
        The com.sun.star.lang.XComponent interface of the controller must be used to recognize when it is deleted.
        """
    def disconnectController(self, Controller: 'XController_b00e0b8f') -> None:
        """
        is called whenever an existing controller should be deregistered at this model.
        
        The com.sun.star.lang.XComponent interface of the controller must be used to recognize when it is deleted.
        """
    def getArgs(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        provides read access on currently representation of the com.sun.star.document.MediaDescriptor of this model which describes the model and its state
        """
    def getCurrentController(self) -> 'XController_b00e0b8f':
        """
        provides access to the controller which currently controls this model
        """
    def getCurrentSelection(self) -> 'XInterface_8f010a43':
        """
        provides read access on current selection on controller
        """
    def getURL(self) -> str:
        """
        provides information about the location of this model
        """
    def hasControllersLocked(self) -> bool:
        """
        determines if there is at least one lock remaining.
        
        While there is at least one lock remaining, some notifications for display updates are not broadcasted to the controllers.
        """
    def lockControllers(self) -> None:
        """
        suspends some notifications to the controllers which are used for display updates.
        
        The calls to XModel.lockControllers() and XModel.unlockControllers() may be nested and even overlapping, but they must be in pairs. While there is at least one lock remaining, some notifications for display updates are not broadcasted.
        """
    def setCurrentController(self, Controller: 'XController_b00e0b8f') -> None:
        """
        sets a registered controller as the current controller.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def unlockControllers(self) -> None:
        """
        resumes the notifications which were suspended by XModel.lockControllers().
        
        The calls to XModel.lockControllers() and XModel.unlockControllers() may be nested and even overlapping, but they must be in pairs. While there is at least one lock remaining, some notifications for display updates are not broadcasted.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.datatransfer.clipboard.clipboard_event import ClipboardEvent as ClipboardEvent
from ..._pyi.datatransfer.clipboard.clipboard_manager import ClipboardManager as ClipboardManager
from ..._pyi.datatransfer.clipboard.generic_clipboard import GenericClipboard as GenericClipboard
from ..._pyi.datatransfer.clipboard.system_clipboard import SystemClipboard as SystemClipboard
from ..._pyi.datatransfer.clipboard.x_clipboard import XClipboard as XClipboard
from ..._pyi.datatransfer.clipboard.x_clipboard_ex import XClipboardEx as XClipboardEx
from ..._pyi.datatransfer.clipboard.x_clipboard_factory import XClipboardFactory as XClipboardFactory
from ..._pyi.datatransfer.clipboard.x_clipboard_listener import XClipboardListener as XClipboardListener
from ..._pyi.datatransfer.clipboard.x_clipboard_manager import XClipboardManager as XClipboardManager
from ..._pyi.datatransfer.clipboard.x_clipboard_notifier import XClipboardNotifier as XClipboardNotifier
from ..._pyi.datatransfer.clipboard.x_clipboard_owner import XClipboardOwner as XClipboardOwner
from ..._pyi.datatransfer.clipboard.x_flushable_clipboard import XFlushableClipboard as XFlushableClipboard
from ..._pyi.datatransfer.clipboard.x_system_clipboard import XSystemClipboard as XSystemClipboard



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.resource
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XLocale(XInterface_8f010a43):
    """
    offers some operations on com.sun.star.lang.Locale structures.

    See Also:
        `API XLocale <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1resource_1_1XLocale.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.resource.XLocale']

    def create(self, aLanguage: str, aCountry: str, aVariant: str) -> 'Locale_70d308fa':
        """
        creates a locale from language, country, and variant.
        
        NOTE: ISO 639 is not a stable standard; some of the language codes it defines (specifically iw, ji, and in) have changed. This constructor accepts both the old codes (iw, ji, and in) and the new codes (he, yi, and id), but all other API on XLocale will return only the NEW codes.
        
        Note: The Java class Locale returns the old codes.
        """
    def equals(self, l1: 'Locale_70d308fa', l2: 'Locale_70d308fa') -> bool:
        """
        A locale is deemed equal to another locale with identical language, country, and variant, and unequal to all other objects.
        """
    def getAvailableLocales(self) -> 'typing.Tuple[Locale_70d308fa, ...]':
        """
        """
    def getDefault(self) -> 'Locale_70d308fa':
        """
        the common method of getting the current default locale.
        
        It is used for the presentation (for menus, dialogs, etc.). It is, generally, set once when your applet or application is initialized, then never reset. (If you do reset the default locale, you probably want to reload your GUI, so that the change is reflected in your interface.)
        
        More advanced programs allow users to use different locales for different fields, for example, in a spreadsheet.
        
        Note that the initial setting will match the host system.
        """
    def getDisplayCountry(self, locale: 'Locale_70d308fa', inLocale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayCountry_Default(self, locale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayLanguage(self, locale: 'Locale_70d308fa', inLocale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayLanguage_Default(self, locale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayName(self, locale: 'Locale_70d308fa', inLocale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayName_Default(self, locale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayVariant(self, locale: 'Locale_70d308fa', inLocale: 'Locale_70d308fa') -> str:
        """
        """
    def getDisplayVariant_Default(self, locale: 'Locale_70d308fa') -> str:
        """
        """
    def getISO3Country(self, locale: 'Locale_70d308fa') -> str:
        """

        Raises:
            com.sun.star.resource.MissingResourceException: ``MissingResourceException``
        """
    def getISO3Language(self, locale: 'Locale_70d308fa') -> str:
        """

        Raises:
            com.sun.star.resource.MissingResourceException: ``MissingResourceException``
        """
    def getISOCountries(self) -> 'typing.Tuple[str, ...]':
        """
        """
    def getISOLanguages(self) -> 'typing.Tuple[str, ...]':
        """
        """
    def getLanguagesForCountry(self, country: str) -> 'typing.Tuple[str, ...]':
        """
        """
    def setDefault(self, newLocale: 'Locale_70d308fa') -> None:
        """
        sets the default locale for the whole environment.
        
        It is normally set once at the beginning of an application, then never reset. setDefault does not reset the host locale.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XAccessibleStateSet(XInterface_8f010a43):
    """
    Implement this interface to represent a set of states.
    
    The interface XAccessibleStateSet represents a set of states of an accessible object. It can hold any combination of states defined by the constants collection AccessibleStateType.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleStateSet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleStateSet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleStateSet']

    def contains(self, aState: int) -> bool:
        """
        Checks if the given state is a member of the state set of the called object.
        """
    def containsAll(self, aStateSet: 'typing.Tuple[int, ...]') -> bool:
        """
        Checks if all of the given states are in the state set of the called object.
        """
    def getStates(self) -> 'typing.Tuple[int, ...]':
        """
        Get all currently set states as a sequence of state ids.
        
        The purpose of this function is to reduce the communication between accessibility objects and AT. Without this function an AT-Tool had to call contains() for every state type. Now a single call is sufficient.
        """
    def isEmpty(self) -> bool:
        """
        Checks whether the current state set is empty.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.io
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_object_input_stream import XObjectInputStream as XObjectInputStream_dfb60d0b
    from .x_object_output_stream import XObjectOutputStream as XObjectOutputStream_ee190d8c

class XPersistObject(XInterface_8f010a43):
    """
    allows to make UNO objects persistent
    
    Every UNO object, that wants to be serializable, should implement this interface. The object stores stores itself, when the write method is called.
    
    The object needs to be created before it deserializes itself again (by using the read method). Therefore it must be creatable by name via a factory, which is in general the global service manager. The create and read mechanism is implemented by the com.sun.star.io.ObjectInputStream.
    
    The serialization format (the series of strings, integers, objects) must be specified at the specification of the concrete service.
    
    The interface does not support any special versioning mechanism.

    See Also:
        `API XPersistObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XPersistObject.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.io.XPersistObject']

    def getServiceName(self) -> str:
        """
        gives the service name of the object
        
        This name is used to create such an object by a factory during deserialization.
        """
    def read(self, InStream: 'XObjectInputStream_dfb60d0b') -> None:
        """
        reads all the persistent data of the object from the stream.
        
        In case other XPersistObjects are read from the stream, the implementation uses a factory to create these objects (in general the global service manager).
        
        The implementation must read the data in the order documented at the service specification.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def write(self, OutStream: 'XObjectOutputStream_ee190d8c') -> None:
        """
        writes all the persistent data of the object to the stream.
        
        The implementation must write the data in the order documented in the service specification.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from ..beans.x_exact_name import XExactName as XExactName_a3310adf
from ..beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates_2a3e0f4d
from ..beans.x_property_set_info import XPropertySetInfo as XPropertySetInfo_efa90d86
from ..beans.x_property_state import XPropertyState as XPropertyState_d55c0ccf
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess_9e2611b5
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class HierarchyAccess(XExactName_a3310adf, XMultiPropertyStates_2a3e0f4d, XPropertySetInfo_efa90d86, XPropertyState_d55c0ccf, XContainer_d6fb0cc6, XHierarchicalNameAccess_9e2611b5, XNameAccess_e2ab0cf6):
    """
    Service Class

    provides access to a hierarchy of descendant elements.
    
    Subnodes are accessed by their name. Values that are direct or indirect descendants of this tree node can be retrieved. Non-value subnodes can be navigated using container interfaces. Other interfaces provide access to information about this node. Changes to values in the subtree can be monitored by event listeners.
    
    Elements of this container that are not simple values are similar containers themselves, thus (recursively) forming a hierarchical tree.
    
    Implementations of this service usually also implement service HierarchyElement, which concerns the complementary role of being accessible as an element of the hierarchy.

    See Also:
        `API HierarchyAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1HierarchyAccess.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter_271e0eed
from .data_result import DataResult as DataResult_a47d0b1a


class DataPilotTableResultData(object):
    """
    Struct Class

    information about a cell positioned within the result area of a DataPilot table.
    
    DataPilotTableResultData contains information about a particular cell positioned within the result area of a DataPilot table.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTableResultData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableResultData.html>`_
    """
    typeName: Literal['com.sun.star.sheet.DataPilotTableResultData']

    def __init__(self, FieldFilters: typing.Optional[typing.Tuple[DataPilotFieldFilter_271e0eed, ...]] = ..., DataFieldIndex: typing.Optional[int] = ..., Result: typing.Optional[DataResult_a47d0b1a] = ...) -> None:
        """
        Constructor

        Arguments:
            FieldFilters (typing.Tuple[DataPilotFieldFilter, ...], optional): FieldFilters value.
            DataFieldIndex (int, optional): DataFieldIndex value.
            Result (DataResult, optional): Result value.
        """


    @property
    def FieldFilters(self) -> typing.Tuple[DataPilotFieldFilter_271e0eed, ...]:
        """
        This is a set of filter criteria that can be used to re-create those data rows that contribute to the value shown in the cell.
        """


    @property
    def DataFieldIndex(self) -> int:
        """
        This is a 0-based index that specifies which data field the data displayed in the cell is for; the value of 0 means the cell is for the first data field, 1 for the second, and so on.
        """


    @property
    def Result(self) -> DataResult_a47d0b1a:
        """
        more information about the result contained in the DataResult type.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API InterruptReason <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1script.html#a298e9238891ddece524d1b3732aa33e4>`_
"""

BreakPoint: 'uno.Enum'
"""
script stopped at a breakpoint.
"""
Cancel: 'uno.Enum'
"""
script in the engine was cancelled.

script execution was cancelled.
"""
CompileError: 'uno.Enum'
"""
script has invalid syntax.
"""
RuntimeError: 'uno.Enum'
"""
runtime error occurred during script execution.
"""
Step: 'uno.Enum'
"""
script stops because only one scripting engine command was executed.
"""
StepOut: 'uno.Enum'
"""
script stops because it leaves a function.
"""
StepOver: 'uno.Enum'
"""
script stops because one step was executed.
"""
StepStatement: 'uno.Enum'
"""
script stop because one step was executed.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb.tools
from typing_extensions import Literal
import typing
from .x_connection_supplier import XConnectionSupplier as XConnectionSupplier_57f3105c
if typing.TYPE_CHECKING:
    from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XTableRename(XConnectionSupplier_57f3105c):
    """
    allows to rename table.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XTableRename <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableRename.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.tools.XTableRename']

    def rename(self, table: 'XPropertySet_bc180bfa', newName: str) -> None:
        """
        rename the given table to the new name

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the width of the characters of a font.

They may be expanded in future versions.

See Also:
    `API FontWidth <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontWidth.html>`_
"""
DONTKNOW: float
"""
The width of the font is not specified/known.
"""
ULTRACONDENSED: float
"""
The width of the font is condensed to 50%.
"""
EXTRACONDENSED: float
"""
The width of the font is condensed to 60%.
"""
CONDENSED: float
"""
The width of the font is condensed to 75%.
"""
SEMICONDENSED: float
"""
The width of the font is condensed to 90%.
"""
NORMAL: float
"""
The width of the font is normal.
"""
SEMIEXPANDED: float
"""
The width of the font is expanded to 110%.
"""
EXPANDED: float
"""
The width of the font is expanded to 150%.
"""
EXTRAEXPANDED: float
"""
The width of the font is expanded to 175%.
"""
ULTRAEXPANDED: float
"""
The width of the font is expanded to 200%.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .calendar_item2 import CalendarItem2 as CalendarItem2_b38f0b23


class Calendar2(object):
    """
    Struct Class

    Calendar items as returned in a sequence by XLocaleData3.getAllCalendars2().
    
    Similar to com.sun.star.i18n.Calendar this provides additional members with a sequence of possessive (genitive case) and partitive case month names for locales that use them, for example Slavic locales. If a locale does not provide the possessive form in GenitiveMonths, the names are identical to the nominative case nouns in Calendar.Months. If a locale does not provide the partitive case in PartitiveMonths, the names are identical to GenitiveMonths.
    
    The sequences are of type com.sun.star.i18n.CalendarItem2 instead of com.sun.star.i18n.CalendarItem, with the additional NarrowName member.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API Calendar2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1Calendar2.html>`_
    """
    typeName: Literal['com.sun.star.i18n.Calendar2']

    def __init__(self, Days: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = ..., Months: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = ..., GenitiveMonths: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = ..., PartitiveMonths: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = ..., Eras: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = ..., StartOfWeek: typing.Optional[str] = ..., MinimumNumberOfDaysForFirstWeek: typing.Optional[int] = ..., Default: typing.Optional[bool] = ..., Name: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Days (typing.Tuple[CalendarItem2, ...], optional): Days value.
            Months (typing.Tuple[CalendarItem2, ...], optional): Months value.
            GenitiveMonths (typing.Tuple[CalendarItem2, ...], optional): GenitiveMonths value.
            PartitiveMonths (typing.Tuple[CalendarItem2, ...], optional): PartitiveMonths value.
            Eras (typing.Tuple[CalendarItem2, ...], optional): Eras value.
            StartOfWeek (str, optional): StartOfWeek value.
            MinimumNumberOfDaysForFirstWeek (int, optional): MinimumNumberOfDaysForFirstWeek value.
            Default (bool, optional): Default value.
            Name (str, optional): Name value.
        """


    @property
    def Days(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The days of the week.
        """


    @property
    def Months(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The months of the year.
        """


    @property
    def GenitiveMonths(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The months of the year in possessive genitive case.
        """


    @property
    def PartitiveMonths(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The months of the year in partitive case.
        """


    @property
    def Eras(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The possible eras.
        """


    @property
    def StartOfWeek(self) -> str:
        """
        The ID of the day with which the week begins.
        """


    @property
    def MinimumNumberOfDaysForFirstWeek(self) -> int:
        """
        How many days must reside in the first week of a year.
        """


    @property
    def Default(self) -> bool:
        """
        If this is the default calendar for a given locale.
        """


    @property
    def Name(self) -> str:
        """
        The name of the calendar, for example, Gregorian.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from .x_index_entry_supplier import XIndexEntrySupplier as XIndexEntrySupplier_1cb0dfe
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XExtendedIndexEntrySupplier(XIndexEntrySupplier_1cb0dfe):
    """
    This interface provides information for creating \"Table of Index\".
    
    It is derived from com.sun.star.i18n.XIndexEntrySupplier and provides following additional functionalities.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XExtendedIndexEntrySupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedIndexEntrySupplier.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XExtendedIndexEntrySupplier']

    def compareIndexEntry(self, aIndexEntry1: str, aPhoneticEntry1: str, aLocale1: 'Locale_70d308fa', aIndexEntry2: str, aPhoneticEntry2: str, aLocale2: 'Locale_70d308fa') -> int:
        """
        Compares index entries.
        
        Note that loadAlgorithm should be called before calling this function.
        """
    def getAlgorithmList(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        Returns index algorithm list for specific locale.
        """
    def getIndexKey(self, aIndexEntry: str, aPhoneticEntry: str, aLocale: 'Locale_70d308fa') -> str:
        """
        Returns index key.
        
        Note that loadAlgorithm should be called before calling this function.
        """
    def getLocaleList(self) -> 'typing.Tuple[Locale_70d308fa, ...]':
        """
        Returns locale list for which the IndexEntrySupplier provides service.
        """
    def getPhoneticCandidate(self, aIndexEntry: str, aLocale: 'Locale_70d308fa') -> str:
        """
        Returns phonetic candidate for index entry for the locale.
        """
    def loadAlgorithm(self, aLocale: 'Locale_70d308fa', aIndexAlgorithm: str, nCollatorOptions: int) -> bool:
        """
        Loads index algorithm for the locale.
        """
    def usePhoneticEntry(self, aLocale: 'Locale_70d308fa') -> bool:
        """
        Checks if Phonetic Entry should be used for the locale.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.packages.zip
from typing_extensions import Literal


class ZipConstants(object):
    """
    Const

    defines the constants used by the ZIP interfaces.

    See Also:
        `API ZipConstants <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1packages_1_1zip_1_1ZipConstants.html>`_
    """
    DEFLATED: Literal[8]
    """
    Compression method for the deflate algorithm (the only one currently supported).
    """
    NO_COMPRESSION: Literal[0]
    """
    Compression level for no compression.
    """
    BEST_SPEED: Literal[1]
    """
    Compression level for fastest compression.
    """
    BEST_COMPRESSION: Literal[9]
    """
    Compression level for best compression.
    """
    DEFAULT_COMPRESSION: Literal[-1]
    """
    Default compression level.
    """
    FILTERED: Literal[1]
    """
    Compression strategy best used for data consisting mostly of small values with a somewhat random distribution.
    
    Forces more Huffman coding and less string matching.
    """
    HUFFMAN_ONLY: Literal[2]
    """
    Compression strategy for Huffman coding only.
    """
    DEFAULT_STRATEGY: Literal[0]
    """
    Default compression strategy.
    """
    STORED: Literal[0]
    """
    entry is uncompressed
    """
    DEF_MEM_LEVEL: Literal[8]
    """
    entry is uncompressed
    """
    LOCSIG: Literal[67324752]
    """
    Header Signature: \"PK\\003\\004\".
    """
    EXTSIG: Literal[134695760]
    """
    Header Signature: \"PK\\007\\008\".
    """
    CENSIG: Literal[33639248]
    """
    Header Signature: \"PK\\001\\002\".
    """
    ENDSIG: Literal[101010256]
    """
    Header Signature: \"PK\\005\\006\".
    """
    SPANSIG: Literal[134695760]
    """
    Header Signature: \"PK\\007\\008\".
    """
    LOCHDR: Literal[30]
    """
    LOC header size in bytes (including signatures)
    """
    EXTHDR: Literal[16]
    """
    EXT header size in bytes (including signatures)
    """
    CENHDR: Literal[46]
    """
    CEN header size in bytes (including signatures)
    """
    ENDHDR: Literal[22]
    """
    END header size in bytes (including signatures)
    """
    LOCVER: Literal[4]
    """
    LOC LOC LOC.
    
    LOC header field \"version needed to extract\" offset
    """
    LOCFLG: Literal[6]
    """
    LOC header field \"general purpose bit flags\" offset.
    """
    LOCHOW: Literal[8]
    """
    LOC header field \"compression method\" offset.
    """
    LOCTIM: Literal[10]
    """
    LOC header field \"modification time\" offset.
    """
    LOCCRC: Literal[14]
    """
    LOC header field \"CRC of uncompressed data\" offset.
    """
    LOCSIZ: Literal[18]
    """
    LOC header field \"compressed data size\" offset.
    """
    LOCLEN: Literal[22]
    """
    LOC header field \"uncompressed data size\" offset.
    """
    LOCNAM: Literal[26]
    """
    LOC header field \"filename length\" offset.
    """
    LOCEXT: Literal[28]
    """
    LOC header field \"extra field length\" offset.
    """
    EXTCRC: Literal[4]
    """
    EXT header field \"CRC of uncompressed data\" offsets.
    """
    EXTSIZ: Literal[8]
    """
    EXT header field \"compressed size\" offsets.
    """
    EXTLEN: Literal[12]
    """
    EXT header field \"uncompressed size\" offsets.
    """
    CENVEM: Literal[4]
    """
    CEN header field \"version made by\" offset.
    """
    CENVER: Literal[6]
    """
    CEN header field \"version needed to extract\" offset.
    """
    CENFLG: Literal[8]
    """
    CEN header field \"general purpose bit flags\" offset.
    """
    CENHOW: Literal[10]
    """
    CEN header field \"compression method\" offset.
    """
    CENTIM: Literal[12]
    """
    CEN header field \"modification time\" offset.
    """
    CENDAT: Literal[14]
    """
    CEN header field \"modification time\" offset.
    """
    CENCRC: Literal[16]
    """
    CEN header field \"CRC of uncompressed data\" offset.
    """
    CENSIZ: Literal[20]
    """
    CEN header field \"compressed size\" offset.
    """
    CENLEN: Literal[24]
    """
    CEN header field \"uncompressed size\" offset.
    """
    CENNAM: Literal[28]
    """
    CEN header field \"length of filename\" offset.
    """
    CENEXT: Literal[30]
    """
    CEN header field \"length of extra field\" offset.
    """
    CENCOM: Literal[32]
    """
    CEN header field \"file comment length\" offset.
    """
    CENDSK: Literal[34]
    """
    CEN header field \"disk number start\" offset.
    """
    CENATT: Literal[36]
    """
    CEN header field \"internal file attributes\" offset.
    """
    CENATX: Literal[38]
    """
    CEN header field \"external file attributes\" offset.
    """
    CENOFF: Literal[42]
    """
    CEN header field \"offset of local header\" offset.
    """
    ENDSUB: Literal[8]
    """
    END header field \"number of entries on this disk\" offset.
    """
    ENDTOT: Literal[10]
    """
    END header field \"total number of entries\" offset.
    """
    ENDSIZ: Literal[12]
    """
    END header field \"central directory size\" offset.
    """
    ENDOFF: Literal[16]
    """
    END header field \"central directory offset\" offset.
    """
    ENDCOM: Literal[20]
    """
    END header field \"size of zip file comment\" offset.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
"""
Const

specifies the property type of an entry in a conversion dictionary.

**since**

    OOo 2.0

See Also:
    `API ConversionPropertyType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1ConversionPropertyType.html>`_
"""
NOT_DEFINED: Literal[0]
"""
There is no property type defined or available.
"""
OTHER: Literal[1]
"""
Any word that does not fit into any of the other properties.
"""
FOREIGN: Literal[2]
"""
A word or term that is transliterated or used from a non-Chinese language.
"""
FIRST_NAME: Literal[3]
"""
The first name (given name) of a person.
"""
LAST_NAME: Literal[4]
"""
The last name (family name) of a person.
"""
TITLE: Literal[5]
"""
The academic or social title of a person.
"""
STATUS: Literal[6]
"""
The status of a situation.
"""
PLACE_NAME: Literal[7]
"""
The name of a location or place.
"""
BUSINESS: Literal[8]
"""
The description of a business.
"""
ADJECTIVE: Literal[9]
"""
An adjective.
"""
IDIOM: Literal[10]
"""
A term that is used to literally describe a circumstance.
"""
ABBREVIATION: Literal[11]
"""
An abbreviation.
"""
NUMERICAL: Literal[12]
"""
A numeric word.
"""
NOUN: Literal[13]
"""
A noun.
"""
VERB: Literal[14]
"""
A verb.
"""
BRAND_NAME: Literal[15]
"""
The name of a product or a company.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart
import typing
from .chart_axis_x_supplier import ChartAxisXSupplier as ChartAxisXSupplier_a950e4d
from .chart_axis_z_supplier import ChartAxisZSupplier as ChartAxisZSupplier_aa70e4f
from .chart_statistics import ChartStatistics as ChartStatistics_e2190d37
from .chart_two_axis_y_supplier import ChartTwoAxisYSupplier as ChartTwoAxisYSupplier_380d0f88
from .diagram import Diagram as Diagram_844409cf
from .dim3_d_diagram import Dim3DDiagram as Dim3DDiagram_b7a60b60
from .stackable_diagram import StackableDiagram as StackableDiagram_ee760d59
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class LineDiagram(ChartAxisXSupplier_a950e4d, ChartAxisZSupplier_aa70e4f, ChartStatistics_e2190d37, ChartTwoAxisYSupplier_380d0f88, Diagram_844409cf, Dim3DDiagram_b7a60b60, StackableDiagram_ee760d59):
    """
    Service Class

    specifies line, spline and symbol diagrams.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API LineDiagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1LineDiagram.html>`_
    """
    @property
    def Lines(self) -> bool:
        """
        determines if the chart type has lines connecting the data points or contains just symbols.
        """
    @property
    def SplineOrder(self) -> int:
        """
        specifies the power of the polynomials used for spline calculation
        
        This property is only valid for B-splines
        """
    @property
    def SplineResolution(self) -> int:
        """
        determines the number of sampling points of a spline
        """
    @property
    def SplineType(self) -> int:
        """
        determines if the chart is a spline-chart type and specifies the type of splines.
        
        You can set the following values:
        """
    @property
    def SymbolBitmap(self) -> 'XGraphic_a4da0afc':
        """
        Set this property to a graphic object which is then used as symbol for all series.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def SymbolBitmapURL(self) -> str:
        """
        Set this property to any valid URL that points to a graphic file.
        
        This graphic is then used as symbol for all series.
        
        When you query this value you get an internal URL of the embedded graphic.
        """
    @property
    def SymbolSize(self) -> 'Size_576707ef':
        """
        specifies the size of symbols in 1/100th of a millimeter.
        """
    @property
    def SymbolType(self) -> int:
        """
        determines which type of symbols are displayed.
        
        In this interface, only the two values ChartSymbolType.NONE and ChartSymbolType.AUTO are supported. Later versions may support the selection of the symbols shape.
        
        If you set this property to ChartSymbolType.AUTO, you can change the symbol shape for objects supporting the service ChartDataPointProperties or ChartDataRowProperties.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.lang
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_event_listener import XEventListener as XEventListener_c7230c4a

class XComponent(XInterface_8f010a43):
    """
    allows to explicitly free resources and break cyclic references.
    
    Actually the real lifetime of a UNO object is controlled by references kept on interfaces of this object. But there are two distinct meanings in keeping a reference to an interface: 1st to own the object and 2nd to know the object.
    
    You are only allowed to keep references of interfaces to UNO objects if you are by definition the owner of that object or your reference is very temporary or you have registered an EventListener at that object and release the reference when \"disposing\" is called.

    See Also:
        `API XComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XComponent.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.lang.XComponent']

    def addEventListener(self, xListener: 'XEventListener_c7230c4a') -> None:
        """
        adds an event listener to the object.
        
        The broadcaster fires the disposing method of this listener if the XComponent.dispose() method is called.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        
        If this XComponent is already disposed when XComponent.addEventListener() is called, the call will not fail with a DisposedException, but the caller will be notified via the XEventListener.disposing() callback. This callback can occur synchronously within the addEventListener() call.
        """
    def dispose(self) -> None:
        """
        The owner of an object calls this method to explicitly free all resources kept by this object and thus break cyclic references.
        
        Only the owner of this object is allowed to call this method. The object should release all resources and references in the easiest possible manner ( for instance no serialization should take place anymore ).
        
        The object must notify all registered listeners using the method XEventListener.disposing(). All notified objects should release there references to this object without calling XComponent.removeEventListener() (the disposed object will release the listeners eitherway).
        
        After this method has been called, the object should behave as passive as possible, thus it should ignore all calls in case it can comply with its specification (for instance addEventListener()). Often the object can't fulfill its specification anymore, in this case it must throw the DisposedException (which is derived from com.sun.star.uno.RuntimeException) when it gets called.
        
        For some objects no real owner can be identified, thus it can be disposed from multiple reference holders. In this case the object should be able to cope with multiple dispose()-calls (which are inevitable in a multithreaded environment).
        """
    def removeEventListener(self, aListener: 'XEventListener_c7230c4a') -> None:
        """
        removes an event listener from the listener list.
        
        It is a \"noop\" if the specified listener is not registered.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        
        If this XComponent is already disposed when XComponent.removeEventListener() is called, the call will not fail with a DisposedException, but will rather be ignored silently.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..frame.x_frame import XFrame as XFrame_7a570956
    from .x_decks import XDecks as XDecks_5e8b0828
    from .x_sidebar import XSidebar as XSidebar_704a08f8

class XSidebarProvider(XInterface_8f010a43):
    """
    Interface of the sidebar.
    
    **since**
    
        LibreOffice 5.1

    See Also:
        `API XSidebarProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XSidebarProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XSidebarProvider']

    def getDecks(self) -> 'XDecks_5e8b0828':
        """
        """
    def getFrame(self) -> 'XFrame_7a570956':
        """
        Get the XFrame owner.
        """
    def getSidebar(self) -> 'XSidebar_704a08f8':
        """
        Returns the sidebar object.
        """
    def isVisible(self) -> bool:
        """
        Is the sidebar visible.
        """
    def setVisible(self, bVisible: bool) -> None:
        """
        Display the sidebar.
        """
    def showDecks(self, bVisible: bool) -> None:
        """
        Decks container visibility.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API LineEndType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168>`_
"""

ARROW: 'uno.Enum'
"""
the line uses an arrow for the line end.
"""
CIRCLE: 'uno.Enum'
"""
the line uses a circle for the line end.
"""
NONE: 'uno.Enum'
"""
the area is not filled.

The text size is only defined by the font properties.

Don't animate this text.

the line is hidden.

the joint between lines will not be connected

the line has no special end.
"""
SPECIAL: 'uno.Enum'
"""
not implemented, yet.

deprecated
"""
SQUARE: 'uno.Enum'
"""
the line will get a half square as additional cap

the line uses a square for the line end.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.grid
from typing_extensions import Literal
import typing
from ...container.x_container import XContainer as XContainer_d6fb0cc6
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...util.x_cloneable import XCloneable as XCloneable_99d00aa3
if typing.TYPE_CHECKING:
    from .x_grid_column import XGridColumn as XGridColumn_d2370c74

class XGridColumnModel(XContainer_d6fb0cc6, XComponent_98dc0ab5, XCloneable_99d00aa3):
    """
    An instance of this interface is used by the UnoControlGrid to retrieve the column structure that is displayed in the actual control.
    
    If you do not need your own model implementation, you can also use the DefaultGridColumnModel.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XGridColumnModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.grid.XGridColumnModel']

    def addColumn(self, column: 'XGridColumn_d2370c74') -> int:
        """
        Adds a column to the model.
        
        You should use the createColumn() member to create a new column. This gives implementations of the XGridColumnModel interface the possibility to provide own column implementations which extend the basic GridColumn type.
        
        As soon as the column has been inserted into the model, the model takes ownership of it. This means when the column is removed, or when the column model is disposed, the grid column is disposed as well.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createColumn(self) -> 'XGridColumn_d2370c74':
        """
        creates a new column for use with the column model.
        
        The newly created column is not yet inserted into the column container, you need to call addColumn() after you initialized the column object.
        """
    def getColumn(self, index: int) -> 'XGridColumn_d2370c74':
        """
        Returns a specific column.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getColumnCount(self) -> int:
        """
        Returns the number of columns.
        """
    def getColumns(self) -> 'typing.Tuple[XGridColumn_d2370c74, ...]':
        """
        Returns all columns of the model.
        """
    def removeColumn(self, ColumnIndex: int) -> None:
        """
        removes a column from the model
        
        The column object will be disposed upon removal.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setDefaultColumns(self, elements: int) -> None:
        """
        Fills the model with the given number of default columns.
        
        Existing columns will be removed before adding new columns. Listeners at the column model will be notified one com.sun.star.container.XContainerListener.elementRemoved() event for each removed column, and one com.sun.star.container.XContainerListener.elementInserted() event for each insertion.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rdf
from typing_extensions import Literal


class FileFormat(object):
    """
    Const

    Constants to specify RDF file formats.
    
    These constants are mainly for use with XRepository.importGraph() and XRepository.exportGraph().
    
    Note that these are integers because UNO IDL does not permit string constants.
    
    **since**
    
        OOo 3.0

    See Also:
        `API FileFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rdf_1_1FileFormat.html>`_
    """
    RDF_XML: Literal[0]
    """
    RDF/XML
    """
    N3: Literal[1]
    """
    N3 (Notation-3)
    """
    NTRIPLES: Literal[2]
    """
    N-Triples
    """
    TRIG: Literal[3]
    """
    TriG
    """
    TRIX: Literal[4]
    """
    TriX
    """
    TURTLE: Literal[5]
    """
    Turtle
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class TransferInfo(object):
    """
    Struct Class

    contains information needed to transfer objects from one location to another.
    
    The transfer command is always called on the target folder. For a details description of the transfer command refer to the documentation of service Content.

    See Also:
        `API TransferInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1TransferInfo.html>`_
    """
    typeName: Literal['com.sun.star.ucb.TransferInfo']

    def __init__(self, MoveData: typing.Optional[bool] = ..., SourceURL: typing.Optional[str] = ..., NewTitle: typing.Optional[str] = ..., NameClash: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            MoveData (bool, optional): MoveData value.
            SourceURL (str, optional): SourceURL value.
            NewTitle (str, optional): NewTitle value.
            NameClash (int, optional): NameClash value.
        """


    @property
    def MoveData(self) -> bool:
        """
        contains the flags describing whether the data shall be moved instead of copied.
        """


    @property
    def SourceURL(self) -> str:
        """
        contains the URL of the source of the action (e.g.
        
        the URL of a file to move).
        """


    @property
    def NewTitle(self) -> str:
        """
        contains the title of the transferred object, if it is different from the original one.
        
        If this field is filled, for example, a file will be renamed while it is being transferred.
        """


    @property
    def NameClash(self) -> int:
        """
        describes how to act in case of title clashes while transferring the data.
        
        A title clash for instance occurs, if a file named \"foo.txt\" is to be transferred to a folder already containing another file named \"foo.txt\".
        
        The value can be one of the NameClash constants.
        
        Implementations that are not able to detect whether there is a clashing resource may ignore NameClash.ERROR and NameClash.RENAME always write the new data.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_storage import XStorage as XStorage_8e460a32
    from ..frame.x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor_afda1275

class EmbeddedObjectDescriptor(ABC):
    """
    Service Class

    describes properties of an embedded object
    
    This service may be represented by a com.sun.star.beansPropertyValue[]. Such descriptors will be passed to different functions, included into possible load/save processes. Every member of such process can use this descriptor and may change it to actualize the information about the object. So this descriptor should be used as an in/out parameter.

    See Also:
        `API EmbeddedObjectDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1EmbeddedObjectDescriptor.html>`_
    """
    @property
    def OutplaceDispatchInterceptor(self) -> 'XDispatchProviderInterceptor_afda1275':
        """
        allows to provide a dispatch interceptor for outplace activation.
        """
    @property
    def RecoveryStorage(self) -> 'XStorage_8e460a32':
        """
        denotes the storage from which the embedded object is to be recovered.
        
        Upon activating the embedded object, it is normally loaded from a storage as denoted by the parameters to the XEmbedObjectCreator method calls.
        
        You can pass a non-NULL RecoveryStorage in the object descriptor if you wish to load the embedded object from an alternate storage.
        
        The object will still be based on the storage denoted in the XEmbedObjectCreator method call, i.e., subsequent save operations will still use that storage. RecoveryStorage is used at loading time only, and then discarded.
        """
    @property
    def StoreVisualReplacement(self) -> bool:
        """
        lets the graphical representation of embedded document be stored.
        
        Setting of this property to true tells the embedded object that controls the document to store or not to store the graphical representation of the document into the object persistence. If this property is not set the object makes the decision itself.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from .x_array import XArray as XArray_708108fb
    from .x_blob import XBlob as XBlob_6773087b
    from .x_clob import XClob as XClob_6777087c
    from .x_ref import XRef as XRef_5f110819
    from .xsql_data import XSQLData as XSQLData_81fe0966
    from .x_struct import XStruct as XStruct_7a760981
    from ..util.date import Date as Date_60040844
    from ..util.date_time import DateTime as DateTime_84de09d3
    from ..util.time import Time as Time_604e0855

class XSQLOutput(XInterface_8f010a43):
    """
    is used as an output stream for writing the attributes of a user-defined type back to the database.
    
    This interface, used only for custom mapping, is used by the driver, and its methods are never directly invoked by a programmer.
    
    When an object of a class implementing interface com.sun.star.sdbc.XSQLData is passed as an argument to a SQL statement, the JDBC driver calls com.sun.star.sdbc.SQLData.getSQLType() to determine the kind of SQL datum being passed to the database.
    The driver then creates an instance of XSQLOutput and passes it to the method com.sun.star.sdbc.XSQLData.writeSQL() . The method writeSQL in turn calls the appropriate XSQLOutput.writeXXX methods to write data from the com.sun.star.sdbc.XSQLData object to the XSQLOutput output stream as the representation of a SQL user-defined type.

    See Also:
        `API XSQLOutput <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XSQLOutput']

    def writeArray(self, x: 'XArray_708108fb') -> None:
        """
        writes an array to the stream.

        Raises:
            SQLException: ``SQLException``
        """
    def writeBinaryStream(self, x: 'XInputStream_98d40ab4') -> None:
        """
        writes the next attribute to the stream as a stream of uninterpreted bytes.

        Raises:
            SQLException: ``SQLException``
        """
    def writeBlob(self, x: 'XBlob_6773087b') -> None:
        """
        writes a BLOB to the stream.

        Raises:
            SQLException: ``SQLException``
        """
    def writeBoolean(self, x: bool) -> None:
        """
        writes the next attribute to the stream as boolean.

        Raises:
            SQLException: ``SQLException``
        """
    def writeByte(self, x: int) -> None:
        """
        writes the next attribute to the stream as byte.

        Raises:
            SQLException: ``SQLException``
        """
    def writeBytes(self, x: 'typing.Tuple[int, ...]') -> None:
        """
        writes the next attribute to the stream as byte sequence.

        Raises:
            SQLException: ``SQLException``
        """
    def writeCharacterStream(self, x: 'XInputStream_98d40ab4') -> None:
        """
        writes the next attribute to the stream as a stream of Unicode string.

        Raises:
            SQLException: ``SQLException``
        """
    def writeClob(self, x: 'XClob_6777087c') -> None:
        """
        writes a CLOB to the stream.

        Raises:
            SQLException: ``SQLException``
        """
    def writeDate(self, x: 'Date_60040844') -> None:
        """
        writes the next attribute to the stream as a date.

        Raises:
            SQLException: ``SQLException``
        """
    def writeDouble(self, x: float) -> None:
        """
        writes the next attribute to the stream as double.

        Raises:
            SQLException: ``SQLException``
        """
    def writeFloat(self, x: float) -> None:
        """
        writes the next attribute to the stream as float.

        Raises:
            SQLException: ``SQLException``
        """
    def writeInt(self, x: int) -> None:
        """
        writes the next attribute to the stream as long.

        Raises:
            SQLException: ``SQLException``
        """
    def writeLong(self, x: int) -> None:
        """
        writes the next attribute to the stream as hyper.

        Raises:
            SQLException: ``SQLException``
        """
    def writeObject(self, x: 'XSQLData_81fe0966') -> None:
        """
        writes to the stream the data contained in the given XSQLData object.
        
        When the XSQLData object is NULL , this method writes an SQL NULL to the stream. Otherwise, it calls the com.sun.star.sdbc.XSQLData.writeSQL() method of the given object, which writes the object's attributes to the stream. The implementation of the method XSQLData.writeSQL() calls the appropriate XSQLOutput.writeXXX method(s) for writing each of the object's attributes in order.
        The attributes must be read from an com.sun.star.sdbc.XSQLInput input stream and written to an XSQLOutput output stream in the same order in which they were listed in the SQL definition of the user-defined type.

        Raises:
            SQLException: ``SQLException``
        """
    def writeRef(self, x: 'XRef_5f110819') -> None:
        """
        writes a REF(&lt;structured-type&gt;) to the stream.

        Raises:
            SQLException: ``SQLException``
        """
    def writeShort(self, x: int) -> None:
        """
        writes the next attribute to the stream as short.

        Raises:
            SQLException: ``SQLException``
        """
    def writeString(self, x: str) -> None:
        """
        writes the next attribute to the stream as a string.

        Raises:
            SQLException: ``SQLException``
        """
    def writeStruct(self, x: 'XStruct_7a760981') -> None:
        """
        writes a structured-type to the stream.

        Raises:
            SQLException: ``SQLException``
        """
    def writeTime(self, x: 'Time_604e0855') -> None:
        """
        writes the next attribute to the stream as a time.

        Raises:
            SQLException: ``SQLException``
        """
    def writeTimestamp(self, x: 'DateTime_84de09d3') -> None:
        """
        writes the next attribute to the stream as a datetime.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XTerminateListener(XEventListener_c7230c4a):
    """
    has to be provided if an object wants to receive an event when the master environment (e.g., desktop) is terminated.

    See Also:
        `API XTerminateListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XTerminateListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XTerminateListener']

    def notifyTermination(self, Event: 'EventObject_a3d70b03') -> None:
        """
        is called when the master environment is finally terminated.
        
        No veto will be accepted then.
        """
    def queryTermination(self, Event: 'EventObject_a3d70b03') -> None:
        """
        is called when the master environment (e.g., desktop) is about to terminate.
        
        Termination can be intercepted by throwing TerminationVetoException. Interceptor will be the new owner of desktop and should call XDesktop.terminate() after finishing his own operations.

        Raises:
            TerminationVetoException: ``TerminationVetoException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

defines flags for references.

The values can be combined.

See Also:
    `API ReferenceFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html>`_
"""
COLUMN_RELATIVE: Literal[1]
"""
selects a relative column reference.
"""
COLUMN_DELETED: Literal[2]
"""
marks a deleted column reference.
"""
ROW_RELATIVE: Literal[4]
"""
selects a relative row reference.
"""
ROW_DELETED: Literal[8]
"""
marks a deleted row reference.
"""
SHEET_RELATIVE: Literal[16]
"""
selects a relative sheet reference.
"""
SHEET_DELETED: Literal[32]
"""
marks a deleted sheet reference.
"""
SHEET_3D: Literal[64]
"""
selects a 3D sheet reference.
"""
RELATIVE_NAME: Literal[128]
"""
marks a reference from a relative range name.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
"""
Const

The implementation of a FilePicker service may support the usage of different templates.

The following constants define the currently specified templates.

**since**

    LibreOffice 5.3

See Also:
    `API TemplateDescription <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html>`_
"""
FILEOPEN_SIMPLE: Literal[0]
"""
A FileOpen dialog without any additional controls.
"""
FILESAVE_SIMPLE: Literal[1]
"""
A FileSave dialog without any additional controls.
"""
FILESAVE_AUTOEXTENSION_PASSWORD: Literal[2]
"""
A FileSave dialog with additional controls.
"""
FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS: Literal[3]
"""
A FileSave dialog with additional controls.
"""
FILESAVE_AUTOEXTENSION_SELECTION: Literal[4]
"""
A FileSave dialog with additional controls.
"""
FILESAVE_AUTOEXTENSION_TEMPLATE: Literal[5]
"""
A FileSave dialog with additional controls.
"""
FILEOPEN_LINK_PREVIEW_IMAGE_TEMPLATE: Literal[6]
"""
A FileOpen dialog with additional controls.
"""
FILEOPEN_PLAY: Literal[7]
"""
A FileOpen dialog with additional controls.
"""
FILEOPEN_READONLY_VERSION: Literal[8]
"""
A FileOpen dialog with additional controls.
"""
FILEOPEN_LINK_PREVIEW: Literal[9]
"""
A FileOpen dialog with additional controls.
"""
FILESAVE_AUTOEXTENSION: Literal[10]
"""
A FileSave dialog with additional controls.
"""
FILEOPEN_PREVIEW: Literal[11]
"""
A FileOpen dialog with additional controls.

**since**

    LibreOffice 5.3
"""
FILEOPEN_LINK_PLAY: Literal[12]
"""
A FileOpen dialog with additional controls.

**since**

    LibreOffice 5.3
"""
FILEOPEN_LINK_PREVIEW_IMAGE_ANCHOR: Literal[13]
"""
A FileOpen dialog with additional controls.

**since**

    LibreOffice 6.1
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class DataPilotFieldLayoutMode(object):
    """
    Const

    describes the layout mode of the data field

    See Also:
        `API DataPilotFieldLayoutMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutMode.html>`_
    """
    TABULAR_LAYOUT: Literal[0]
    """
    Tabular layout mode is the layout, where each item's name is on the same row as the first item from the following field.
    
    Subtotals are always shown below an item's data in this mode.
    """
    OUTLINE_SUBTOTALS_TOP: Literal[1]
    """
    In outline layout mode, the items from the following field start in the row below an item's name, like in traditional database reports.
    
    Subtotals are shown at the top (on the same row as the item's name). When the subtotals take up more than one row (manually selected, or because there are several data fields), they are always shown below the item's data, regardless of the setting.
    """
    OUTLINE_SUBTOTALS_BOTTOM: Literal[2]
    """
    In outline layout mode, the items from the following field start in the row below an item's name, like in traditional database reports.
    
    Subtotals are shown at the bottom (below the item's data, as in tabular layout mode). When the subtotals take up more than one row (manually selected, or because there are several data fields), they are always shown below the item's data, regardless of the setting.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..beans.x_property_state import XPropertyState as XPropertyState_d55c0ccf
from ..container.x_content_enumeration_access import XContentEnumerationAccess as XContentEnumerationAccess_c71012d7
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4
from .x_text_range import XTextRange as XTextRange_9a910ab7

class TextRange(CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, ParagraphPropertiesAsian_6e8c10e8, ParagraphPropertiesComplex_91de11d4, XPropertySet_bc180bfa, XPropertyState_d55c0ccf, XContentEnumerationAccess_c71012d7, XTextRange_9a910ab7):
    """
    Service Class

    points to a sequence of characters within a Text.
    
    The service provides access to the string content and the properties of this range of text and the TextContent instances which are bound to this text range.
    
    A TextRange is also used for a text portion which is returned by the com.sun.star.container.XEnumeration for a single paragraph. Because this is the mechanism to use to export data, all formatting attributes and contents bound to this range have to be available from implementations of this service.

    See Also:
        `API TextRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextRange.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ValidationType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57a>`_
"""

ANY: 'uno.Enum'
"""
any cell content is valid; no conditions are used.
"""
CUSTOM: 'uno.Enum'
"""
The specified formula determines which contents are valid.
"""
DATE: 'uno.Enum'
"""
specifies an arithmetic series for date values.

any date value matching the specified condition is valid.
"""
DECIMAL: 'uno.Enum'
"""
any number matching the specified condition is valid.
"""
LIST: 'uno.Enum'
"""
Only strings from a specified list are valid.
"""
TEXT_LEN: 'uno.Enum'
"""
string is valid if its length matches the specified condition.
"""
TIME: 'uno.Enum'
"""
any time value matching the specified condition is valid.
"""
WHOLE: 'uno.Enum'
"""
any whole number matching the specified condition is valid.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.view
from abc import ABC

class PrintOptions(ABC):
    """
    Service Class

    describes the options for print jobs.
    
    These options are only valid for a single print job. They do not change layout or formatting of the document.

    See Also:
        `API PrintOptions <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1view_1_1PrintOptions.html>`_
    """
    @property
    def Collate(self) -> bool:
        """
        advises the printer to collate the pages of the copies.
        """
    @property
    def CopyCount(self) -> int:
        """
        specifies the number of copies to print.
        """
    @property
    def DuplexMode(self) -> int:
        """
        determines the duplex mode for the print job.
        """
    @property
    def FileName(self) -> str:
        """
        if set, specifies the name of a file to print to.
        """
    @property
    def Pages(self) -> str:
        """
        specifies which pages to print.
        
        This range is given as at the user interface. For example: \"1-4;10\" to print the pages 1 to 4 and 10.
        """
    @property
    def PrinterName(self) -> str:
        """
        if set, specifies name of the printer to use.
        """
    @property
    def SinglePrintJobs(self) -> bool:
        """
        advises the printer to create a single print job for each copy.
        """
    @property
    def Sort(self) -> bool:
        """
        advises the printer to sort the pages of the copies.
        """
    @property
    def Wait(self) -> bool:
        """
        if set to TRUE, the corresponding XPrintable.print() request will be executed synchronous.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content_provider_manager import XContentProviderManager as XContentProviderManager_37e00f7b

class XRemoteContentProviderActivator(XInterface_8f010a43):
    """
    This interface should be implemented together with XRemoteContentProviderAcceptor and allows for a lazy implementation of XRemoteContentProviderAcceptor.addRemoteContentProvider().
    
    The way this works might change, therefore this interface is marked as deprecated.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XRemoteContentProviderActivator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderActivator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XRemoteContentProviderActivator']

    def activateRemoteContentProviders(self) -> 'XContentProviderManager_37e00f7b':
        """
        Activate (i.e., register at the broker) the remote content providers that until now have only been remembered by XRemoteContentProviderAcceptor.addRemoteContentProvider(), but not registered.
        
        This allows for XRemoteContentProviderAcceptor.addRemoteContentProvider() to be implemented in a lazy fashion (remember the remote content providers, but do not register them right away), which can increase performance in certain situations. But it is not required that an implementation of XRemoteContentProviderAcceptor uses this lazy strategy (and thus also implements this interface).
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.security
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..embed.x_storage import XStorage as XStorage_8e460a32
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_stream import XStream as XStream_678908a4
    from .certificate_kind import CertificateKind as CertificateKind_ffd0e69
    from .document_signature_information import DocumentSignatureInformation as DocumentSignatureInformation_f36c13f7
    from .x_certificate import XCertificate as XCertificate_e55b0d3b

class XDocumentDigitalSignatures(XInterface_8f010a43):
    """
    Interface for signing and verifying digital signatures in office documents.
    
    This interface can be used to digitally sign different content in an office document. It can also be used to verify digital signatures.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API XDocumentDigitalSignatures <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1security_1_1XDocumentDigitalSignatures.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.security.XDocumentDigitalSignatures']

    def addAuthorToTrustedSources(self, Author: 'XCertificate_e55b0d3b') -> None:
        """
        """
    def addLocationToTrustedSources(self, Location: str) -> None:
        """
        """
    def chooseCertificate(self, Description: str) -> 'XCertificate_e55b0d3b':
        """
        This method shows the CertificateChooser dialog, used by document and PDF signing Shows only private certificates.
        
        **since**
        
            LibreOffice 5.3

        * ``Description`` is an out direction argument.
        """
    def chooseCertificateWithProps(self, Properties: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'XCertificate_e55b0d3b':
        """
        This method shows the CertificateChooser dialog, used by document and PDF signing Shows only private certificates and returns usage string in addition to description.
        
        **since**
        
            LibreOffice 6.0

        * ``Properties`` is an out direction argument.
        """
    def chooseEncryptionCertificate(self) -> 'typing.Tuple[XCertificate_e55b0d3b, ...]':
        """
        This method shows the CertificateChooser dialog with all certificates, private and other people's.
        
        Useful when choosing certificate/key for encryption
        
        **since**
        
            LibreOffice 6.0
        """
    def chooseSigningCertificate(self, Description: str) -> 'XCertificate_e55b0d3b':
        """
        This is an alias for 'chooseCertificate', shows the CertificateChooser dialog with private certificates.
        
        **since**
        
            LibreOffice 6.0

        * ``Description`` is an out direction argument.
        """
    def getDocumentContentSignatureDefaultStreamName(self) -> str:
        """
        allows to get the default stream name for storing of the signature of the document content.
        """
    def getPackageSignatureDefaultStreamName(self) -> str:
        """
        allows to get the default stream name for storing of the signature of the package.
        """
    def getScriptingContentSignatureDefaultStreamName(self) -> str:
        """
        allows to get the default stream name for storing of the signature of the scripting content.
        """
    def isAuthorTrusted(self, Author: 'XCertificate_e55b0d3b') -> bool:
        """
        """
    def isLocationTrusted(self, Location: str) -> bool:
        """
        """
    def manageTrustedSources(self) -> None:
        """
        manages trusted sources (Authors and paths )
        """
    def selectSigningCertificate(self, Description: str) -> 'XCertificate_e55b0d3b':
        """
        This shows the certificate selection dialog and allows to only select the certificate without actually signing the document.
        
        **since**
        
            LibreOffice 6.1

        * ``Description`` is an out direction argument.
        """
    def selectSigningCertificateWithType(self, certificateKind: 'CertificateKind_ffd0e69', Description: str) -> 'XCertificate_e55b0d3b':
        """
        This shows the certificate selection dialog and allows to only select the certificate without actually signing the document.
        
        Only certificates of the given type will be shown.
        
        **since**
        
            LibreOffice 6.2

        * ``Description`` is an out direction argument.
        """
    def setParentWindow(self, xParentWindow: 'XWindow_713b0924') -> None:
        """
        Set parent window to use when showing dialogs.
        
        **since**
        
            LibreOffice 6.3
        """
    def showCertificate(self, Certificate: 'XCertificate_e55b0d3b') -> None:
        """
        """
    def showDocumentContentSignatures(self, xStorage: 'XStorage_8e460a32', xSignInStream: 'XInputStream_98d40ab4') -> None:
        """
        shows the digital signatures of the document content
        """
    def showPackageSignatures(self, xStorage: 'XStorage_8e460a32', xSignInStream: 'XInputStream_98d40ab4') -> None:
        """
        shows the digital signatures of the package
        """
    def showScriptingContentSignatures(self, xStorage: 'XStorage_8e460a32', xSignInStream: 'XInputStream_98d40ab4') -> None:
        """
        shows the digital signatures of the scripting content
        """
    def signDocumentContent(self, xStorage: 'XStorage_8e460a32', xSignStream: 'XStream_678908a4') -> bool:
        """
        signs the content of the document including text and pictures.
        
        Macros will not be signed.
        """
    def signDocumentWithCertificate(self, xCertificate: 'XCertificate_e55b0d3b', xStorage: 'XStorage_8e460a32', xStream: 'XStream_678908a4') -> bool:
        """
        Signs the content of the document with the provided certificate.
        
        **since**
        
            LibreOffice 6.2
        """
    def signPackage(self, Storage: 'XStorage_8e460a32', xSignStream: 'XStream_678908a4') -> bool:
        """
        signs the full Package, which means everything in the storage except the content of META-INF
        """
    def signPackageWithCertificate(self, xCertificate: 'XCertificate_e55b0d3b', xStorage: 'XStorage_8e460a32', xStream: 'XStream_678908a4') -> bool:
        """
        signs the full Package, which means everything in the storage except the content of META-INF with the provided certificate.
        
        **since**
        
            LibreOffice 7.0
        """
    def signScriptingContent(self, xStorage: 'XStorage_8e460a32', xSignStream: 'XStream_678908a4') -> bool:
        """
        signs the content of the Scripting including macros and basic dialogs
        
        The rest of document content will not be signed.
        """
    def signScriptingContentWithCertificate(self, xCertificate: 'XCertificate_e55b0d3b', xStorage: 'XStorage_8e460a32', xStream: 'XStream_678908a4') -> bool:
        """
        signs the content of the Scripting including macros and basic dialogs with the provided certificate.
        
        The rest of document content will not be signed.
        
        **since**
        
            LibreOffice 7.0
        """
    def signSignatureLine(self, xStorage: 'XStorage_8e460a32', xSignStream: 'XStream_678908a4', signatureLineId: str, xCertificate: 'XCertificate_e55b0d3b', xValidGraphic: 'XGraphic_a4da0afc', xInvalidGraphic: 'XGraphic_a4da0afc', comment: str) -> bool:
        """
        Signs the content of the document including text and pictures using the given XCertificate.
        
        Also adds the given Signature Line Id and the signed and unsigned graphics to the signature.
        
        Macros will not be signed.
        
        **since**
        
            LibreOffice 6.1
        """
    def verifyDocumentContentSignatures(self, xStorage: 'XStorage_8e460a32', xSignInStream: 'XInputStream_98d40ab4') -> 'typing.Tuple[DocumentSignatureInformation_f36c13f7, ...]':
        """
        checks for digital signatures and their status.
        
        Only document content will be checked.
        """
    def verifyPackageSignatures(self, Storage: 'XStorage_8e460a32', xSignInStream: 'XInputStream_98d40ab4') -> 'typing.Tuple[DocumentSignatureInformation_f36c13f7, ...]':
        """
        checks for digital signatures and their status.
        
        Only Package content will be checked.
        """
    def verifyScriptingContentSignatures(self, xStorage: 'XStorage_8e460a32', xSignInStream: 'XInputStream_98d40ab4') -> 'typing.Tuple[DocumentSignatureInformation_f36c13f7, ...]':
        """
        checks for digital signatures and their status.
        
        Only Scripting content will be checked.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.validation
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_validity_constraint_listener import XValidityConstraintListener as XValidityConstraintListener_69a2161e

class XValidator(XInterface_8f010a43):
    """
    specifies a component able to validate (the content of) other components
    
    Validators support simple validity checks and retrieving justifications for invalidity.
    
    Validators may additionally support dynamic validity constraints. In such a case, the validity of a given value may change, without the value changing itself.
    To be notified about this, interested components should register as XValidityConstraintListener.

    See Also:
        `API XValidator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1validation_1_1XValidator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.validation.XValidator']

    def addValidityConstraintListener(self, Listener: 'XValidityConstraintListener_69a2161e') -> None:
        """
        registers the given validity listener.
        
        Usually, an XValidatable instance will also add itself as validity listener, as soon as the validator is introduced to it.
        
        Implementations which do not support dynamic validity constraints should simply ignore this call.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
    def explainInvalid(self, Value: object) -> str:
        """
        retrieves a justification for the invalidity of the given value
        """
    def isValid(self, Value: object) -> bool:
        """
        determines whether the given value is valid
        """
    def removeValidityConstraintListener(self, Listener: 'XValidityConstraintListener_69a2161e') -> None:
        """
        revokes the given validity listener

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """

